@@ -8,7 +8,7 @@ our @ISA = qw( Exporter );
 our @EXPORT_OK = qw( ident_server ident_client );
 
 # ABSTRACT: Simple asynchronous ident client and server
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 # keep the server object in scope so that
@@ -17,7 +17,7 @@ our $VERSION = '0.06'; # VERSION
 # for ::Server instead.
 my $keep = [];
 
-sub ident_server
+sub ident_server ($$$;$)
 {
   my $hostname = shift;
   my $port     = shift;
@@ -31,7 +31,7 @@ sub ident_server
 }
 
 
-sub ident_client
+sub ident_client ($$$$$)
 {
   my $hostname = shift;
   my $port     = shift;
@@ -56,7 +56,7 @@ AnyEvent::Ident - Simple asynchronous ident client and server
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -101,51 +101,26 @@ L<AnyEvent::Ident::Server>.
 
 =head1 FUNCTIONS
 
-=head2 ident_server $hostname, $port, $callback
+=head2 ident_server
+
+ my $server = ident_server $hostname, $port, $callback;
+ my $server = ident_server $hostname, $port, $callback, \%opt;
 
 Start an ident server listening to the address given by C<$hostname>
 on port C<$port>.  For each request C<$callback> will be called and
 passed in an instance of L<AnyEvent::Ident::Transaction>.
 
-=head2 ident_client $hostname, $port, $server_port, $client_port, $callback
+C<%opt> is optional hash of arguments.  See L<AnyEvent::Ident::Server#CONSTRUCTOR>
+for legal key/value pairs and defaults.
+
+=head2 ident_client
+
+ my $client = ident_client $hostname, $port, $server_port, $client_port, $callback;
 
 Make an ident request with the ident server at C<$hostname> on port C<$port>
 with the given port pair C<$server_port,$client_port>.  When the response
 comes back call C<$callback>, with an instance of L<AnyEvent::Ident::Response>.
 
-=head1 WHY
-
-Why use this distribution instead of L<Net::Ident>?
-
-=over 4
-
-=item *
-
-Works under Windows (MSWin32)
-
-L<Net::Ident> installs (even passing its tests) on Windows, but it does not work.
-It may not work in some UNIX environments depending on your headers and libraries.
-
-=item *
-
-Works with L<AnyEvent>
-
-This distribution will work with any event loop supported by L<AnyEvent>.
-
-=item *
-
-Server Included
-
-This distribution comes with a server, which is handy for testing (take a
-peek at the test suite for L<Mojolicious::Plugin::Ident> to see what I mean.
-
-=back
-
-Sometimes L<Net::Ident> might be more appropriate.  L<Net::Ident> has only
-core dependencies and will work on older Perls.  This module requires
-L<AnyEvent>.  L<Net::Ident> may be easier to wrap
-your head around if you don't need or want to run under an event loop.
-
 =head1 CAVEATS
 
 ident is an oldish protocol and almost nobody uses it anymore.  The RFC for the
@@ -175,9 +150,23 @@ for clients connecting via the loopback interface (localhost).
 
 =head1 SEE ALSO
 
-L<RFC1413|http://tools.ietf.org/html/rfc1413>,
-L<AnyEvent::Ident::Client>,
-L<AnyEvent::Ident::Server>
+=over 4
+
+=item L<AnyEvent::Ident::Client>
+
+Client OO Interface
+
+=item L<AnyEvent::Ident::Server>
+
+Server OO Interface
+
+=item L<Net::Ident>
+
+Blocking implementation of client only.
+
+=item L<RFC1413|http://tools.ietf.org/html/rfc1413>
+
+=back
 
 =head1 AUTHOR
 
