@@ -11,7 +11,7 @@ use AnyEvent::Ident::Transaction;
 use Carp qw( croak carp );
 
 # ABSTRACT: Simple asynchronous ident server
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 sub new
@@ -107,7 +107,7 @@ AnyEvent::Ident::Server - Simple asynchronous ident server
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -140,39 +140,37 @@ applications, such as IRC).
 
 =head1 CONSTRUCTOR
 
+ my $server = AnyEvent::Ident::Server->new(%args);
+
 The constructor takes the following optional arguments:
 
-=over 4
+=head2 hostname
 
-=item *
-
-hostname (default 127.0.0.1)
+default 127.0.0.1
 
 The hostname to connect to.
 
-=item *
+=head2 port
 
-port (default 113)
+default 113
 
 The port to connect to.
 
-=item *
+=head2 on_error
 
-on_error (carp error)
+default carp error
 
 A callback subref to be called on error (either connection or transmission error).
 Passes the error string as the first argument to the callback.
 
-=item *
-
-on_bind
+=head2 on_bind
 
 A callback subref to be called when the socket has been bound to a port.  Useful
 when using an ephemeral and you do not know the port number in advance.
 
-=back
+=head2 start
 
-=head2 $server-E<gt>start( $callback )
+ $server->start( $callback );
 
 Start the Ident server.  The given callback will be called on each ident
 request (there may be multiple ident requests for each connection).  The
@@ -184,13 +182,17 @@ attributes) and the most important methods on the transaction object are
 C<reply_with_user> and C<reply_with_error> which reply with a successful and 
 error response respectively.
 
-=head2 $server-E<gt>bindport
+=head2 bindport
+
+ my $port = $server->bindport;
 
 The bind port.  If port is set to zero in the constructor or on
 start, then an ephemeral port will be used, and you can get the
 port number here.
 
-=head2 $server-E<gt>stop
+=head2 stop
+
+ $server-E<gt>stop
 
 Stop the server and unbind to the port.
 
