@@ -5,7 +5,7 @@ use warnings;
 use AnyEvent::Ident::Response;
 
 # ABSTRACT: Simple asynchronous ident transaction
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 sub req { shift->{req} }
@@ -59,16 +59,21 @@ AnyEvent::Ident::Transaction - Simple asynchronous ident transaction
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 METHODS
 
-=head2 $tx-E<gt>req
+=head2 req
+
+ my $req = $tx->req;
 
 Returns the request object for the transaction
 (an instance of L<AnyEvent::Ident::Request>).
 
-=head2 $tx-E<gt>reply_with_user( [ $os ], $username )
+=head2 reply_with_user
+
+ $tx->reply_with_user($os, $username);
+ $tx->reply_with_user($os);
 
 Reply to the client with the given username and operating system.  If
 C<$os> is not specified then "OTHER" is used for the operating system.
@@ -91,7 +96,9 @@ The username is actually a real name and phone number.
 
 =back
 
-=head2 $tx-E<gt>reply_with_error( $error_type )
+=head2 reply_with_error
+
+ $tx->reply_with_error( $error_type );
 
 Reply to the client with the given error.  Should be one of
 
@@ -126,15 +133,21 @@ Used for all other errors.
 
 =back
 
-=head2 $tx-E<gt>remote_port
+=head2 remote_port
+
+ my $port = $tx->remote_port;
 
 Returns the remote TCP port being used to make the request.
 
-=head2 $tx-E<gt>local_port
+=head2 local_port
+
+ my $port = $tx->local_port;
 
 Returns the local TCP port being used to make the request.
 
-=head2 $tx-E<gt>remote_address
+=head2 remote_address
+
+ my $address = $tx->remote_address;
 
 Returns the IP address from whence the ident request is coming from.
 
